:: Disclaimer: scripts are provided as-is and most of them use tools that are open source
:: or require a (small) license fee when used in a commercial environment. It is the 
:: responsibility of the end user that use scripts to respect the license agreement for
:: these tools. EFI can not be held responsible in any way if scripts don't behave like
:: they should do resulting in any form of financial loss or downtime. Have a good day.  

:: Process XML to find download url for PDFs
:: Download the PDFs with Aria2

:: Hans Sep, August 2020 - v1

:: User provided arguments
set txtWorkflowName=%~1
:: Manage arguments
shift /1

:: Fiery JobFlow provided arguments
set INPUT=%~1
set OUTPUT=%~2
set JOBNAME=%~n3
set WORKFLOW=%~4
set PREFLIGHT=%~5
set VAULT=%~6
set NEXTMODULEID=%~7

:: Static arguments
set pathScript=%~dp0
set ScriptName=%~n0
set pathLog=%VAULT%\%ScriptName%.log
set pathInclude=%pathScript%\_include
set pathJSON=%VAULT%\params_%NEXTMODULEID%.json

:: Helper Apps
:: #xmlstarlet#
set pathXML=%pathInclude%\xmlstarlet\xml.exe
set pathXSL=%pathScript%\%ScriptName%.xsl
if not exist %pathXML% (
  >>%pathLog% echo %DATE% %TIME% [ERROR] Can't find XMLStarlet at %pathXML%. Exit script.
  exit /b 1
)

:: #aria2#
set pathARIA=%pathInclude%\aria2\aria2c.exe
if not exist "%pathARIA%" (
    >>%pathLog% echo %DATE% %TIME% [ERROR] Can't find %pathARIA%. Exit script.
    exit /b 1
)

:: check user arguments
set pathWORKFLOW=%~d1\SmartFolders\%txtWorkflowName%
if /i "%pathWORKFLOW%" equ "" (
    >>%pathLog% echo %DATE% %TIME% [ERROR] Workflow path is empty or %pathWORKFLOW% does not exist. Exit script.
    exit /b 1
)

if not exist "%pathWORKFLOW%" (
    >>%pathLog% echo %DATE% %TIME% [ERROR] Workflow path is empty or %pathWORKFLOW% does not exist. Exit script.
    exit /b 1
)

:main

:process_xsl
"%pathXML%" tr "%pathXSL%" "%INPUT%" >"%VAULT%\runlist" 2>"%VAULT%\xmlstarlet.log"
if %ERRORLEVEL% NEQ 0 (
  >>%pathLog% echo %DATE% %TIME% [ERROR] An error occured while trying to transform %INPUT% with "%pathXSL%".
  exit /b 1
)

:get_pdfs
"%pathARIA%" -i "%VAULT%\runlist" -d "%pathWORKFLOW%" -l "%VAULT%\aria2c.log"
if %ERRORLEVEL% NEQ 0 (
  >>%pathLog% echo %DATE% %TIME% [ERROR] An error occured while trying to download %VAULT%\runlist.
  exit /b 1
)

:next_module
copy /y "%INPUT%" "%OUTPUT%"
>>%pathLog% echo %DATE% %TIME% [INFO] Copied %INPUT% to %OUTPUT%

:success 
>>%pathLog% echo %DATE% %TIME% [INFO] Done. Exit script.
exit /b 0